function [PR,q] = cca_findsignificance(ret,pval,CFLAG)
%-----------------------------------------------------------------------
% FUNCTION: cca_findsignificance.m
% PURPOSE:  calculate significant Granger causalities
% 
% INPUTS:   ret:    output of cca_granger_regress.m (or similar)
%           pval:   desired P-value threshold
%           CFLAG:  0 = no correction, 1 = Bonferroni, 2 = false discovery
%                   rate, 3 = approx false discovery rate (see ref below)
%
% OUTPUT:   PR:    nvar by nvar matrix of 1s (sig connections)
%           q:     threshold used (=pval for no correction) 
%
%-----------------------------------------------------------------------

prb = ret.prb;
nvar = length(prb);
PR = zeros(nvar);

if CFLAG == 0,   % no correction
    
    PR(prb<pval) = 1;
    q = pval;

elseif CFLAG == 1, % Bonferroni correction
    
    q = pval./(nvar*(nvar-1));
    PR(prb<q) = 1;
    
elseif CFLAG == 2, %  false discovery rate (assuming independent null hypotheses)

    temp = prb(:);
    p = sort(temp);
    q = pval;
    V = length(p);
    I = (1:V)';
    cVID = 1;
    cVN = sum(1./(1:V));
    pID = p(max(find(p<=I/V*q/cVID)));  % independent or positive dependent
    pN = p(max(find(p<=I/V*q/cVN)));    % nonparametric
    % BUG FIX Nov 02
    if isempty(pID),
        pID = -100;
    end
    % END BUG FIX Nov 02
    PR(prb<pID) = 1;    % use independent or +ve
    
    q = pID;

elseif CFLAG == 3, % 'rough' false discovery rate (RFDR), based on average alpha
    
    m = nvar*(nvar-1);
    q = ((m+1)/(2*m))*pval;
    
    PR(prb<q) = 1;
 
else
    error('CFLAG must be 1-3, in cca_findsignificance.m');
end
            
        
     